import getAuthorizationUrl from "../lib/oauth/authorization-url";
import emailSignin from "../lib/email/signin";
/**
 * Handle requests to /api/auth/signin
 * @type {import("types/internals").NextAuthApiHandler}
 */
export default async function signin(req, res) {
    var _a, _b, _c;
    const { baseUrl, basePath, adapter, callbacks, logger } = req.options;
    /** @type {import("types/providers").OAuthConfig | import("types/providers").EmailConfig} */
    const provider = req.options.provider;
    if (!provider.type) {
        return res.status(500).end(`Error: Type not specified for ${provider.name}`);
    }
    if (provider.type === "oauth") {
        try {
            const authorizationUrl = await getAuthorizationUrl(req, res);
            return res.redirect(authorizationUrl);
        }
        catch (error) {
            logger.error("SIGNIN_OAUTH_ERROR", error);
            return res.redirect(`${baseUrl}${basePath}/error?error=OAuthSignin`);
        }
    }
    else if (provider.type === "email") {
        if (!adapter) {
            logger.error("EMAIL_REQUIRES_ADAPTER_ERROR", new Error("E-mail login requires an adapter but it was undefined"));
            return res.redirect(`${baseUrl}${basePath}/error?error=Configuration`);
        }
        // Note: Technically the part of the email address local mailbox element
        // (everything before the @ symbol) should be treated as 'case sensitive'
        // according to RFC 2821, but in practice this causes more problems than
        // it solves. We treat email addresses as all lower case. If anyone
        // complains about this we can make strict RFC 2821 compliance an option.
        const email = (_b = (_a = req.body.email) === null || _a === void 0 ? void 0 : _a.toLowerCase()) !== null && _b !== void 0 ? _b : null;
        const { getUserByEmail } = adapter;
        // If is an existing user return a user object (otherwise use placeholder)
        const user = (_c = (email ? await getUserByEmail(email) : null)) !== null && _c !== void 0 ? _c : { email };
        /** @type {import("types").Account} */
        const account = {
            providerAccountId: user.email,
            type: "email",
            provider: provider.id,
        };
        // Check if user is allowed to sign in
        try {
            const signInCallbackResponse = await callbacks.signIn({
                user,
                account,
                email: { verificationRequest: true },
            });
            if (!signInCallbackResponse) {
                return res.redirect(`${baseUrl}${basePath}/error?error=AccessDenied`);
            }
            else if (typeof signInCallbackResponse === "string") {
                return res.redirect(signInCallbackResponse);
            }
        }
        catch (error) {
            return res.redirect(`${baseUrl}${basePath}/error?${new URLSearchParams({ error })}}`);
        }
        try {
            await emailSignin(email, req.options);
        }
        catch (error) {
            logger.error("SIGNIN_EMAIL_ERROR", error);
            return res.redirect(`${baseUrl}${basePath}/error?error=EmailSignin`);
        }
        const params = new URLSearchParams({
            provider: provider.id,
            type: provider.type,
        });
        const url = `${baseUrl}${basePath}/verify-request?${params}`;
        return res.redirect(url);
    }
    return res.redirect(`${baseUrl}${basePath}/signin`);
}
